@@ -113,6 +113,7 @@ sub read_config {
 							   wily
 							   xenial
 							   yakkety
+							   zesty
 						      )),
 		  user => $>,
 
@@ -164,7 +165,7 @@ sub read_config {
 							   )
 							       ) . ')$',
 		  package_files_regexp => '(?:' . join('|',
-						       qw((?:^|/)%VALID_PACKAGE_NAME%_%VALID_VERSION%(?:_%VALID_ARCHS%\.(?:u|d)?deb|\.dsc|\.tar(?:\.gz|\.bz2|\.xz)|\.diff\.gz)
+						       qw((?:^|/)%VALID_PACKAGE_NAME%_%VALID_VERSION%(?:_%VALID_ARCHS%\.(?:u|d)?deb|\.dsc|\.tar\.(?:gz|bz2|xz|lzma)(?:\.asc)?|\.diff\.gz)
 							  \.rpm
 							  index\.db-.+\.gz
 							  \.jigdo
@@ -559,7 +560,7 @@ sub read_header {
     if ($fh) {
 	for ($fh->getline) {
 	    last unless defined;
-	    if (/^(HTTP\/1\.[01]\s+)?\d{3}\s+/) { # Valid
+	    if (/^(?:HTTP\/1\.[01]\s+)?\d{3}\s+/) { # Valid
 		seek($fh,0,0) || die "Seek failed: $!";
 		{
 		    local $/; # Slurp
